@@ -4,3 +4,8 @@ from .path import AsyncPath, AsyncPurePath, AsyncWindowsPath, \
 
 # export iterable async file handle
 from .handle import IterableAIOFile
+
+
+# convenience aliases
+Path = AsyncPath
+PurePath = AsyncPurePath
