@@ -1,17 +1,17 @@
 from __future__ import annotations
-from pathlib import PosixPath, WindowsPath, _NormalAccessor, \
+from pathlib import PosixPath, WindowsPath, \
   Path, PurePath, _ignore_error
 from typing import AsyncIterable, Final
 from os import stat_result, PathLike
 from stat import S_ISDIR, S_ISLNK, S_ISREG, S_ISSOCK, S_ISBLK, \
   S_ISCHR, S_ISFIFO
-import os
+import os, io
 
-from .selectors import _make_selector
 from .flavours import _async_windows_flavour, _async_posix_flavour
 from .wrap import to_async_method, to_thread, func_to_async_func
-from .handle import get_handle, Handle
 from .scandir import EntryWrapper, scandir_async
+from .handle import get_handle, Handle
+from .selectors import _make_selector
 from .types import FileMode
 
 
@@ -19,6 +19,9 @@ DEFAULT_ENCODING: Final[str] = 'utf-8'
 ON_ERRORS: Final[str] = 'ignore'
 NEWLINE: Final[str] = '\n'
 
+OS_NAME: Final[str] = os.name
+IS_WIN: Final[bool] = OS_NAME == 'nt'
+
 
 Paths = Path | PathLike | str
 
@@ -26,6 +29,89 @@ Paths = Path | PathLike | str
 getcwd = os.getcwd
 close = func_to_async_func(os.close)
 
+# from Python 3.10.8 pathlib.py
+class _Accessor:
+    """An accessor implements a particular (system-specific or not) way of
+    accessing paths on the filesystem."""
+
+class _NormalAccessor(_Accessor):
+
+    stat = os.stat
+
+    open = io.open
+
+    listdir = os.listdir
+
+    scandir = os.scandir
+
+    chmod = os.chmod
+
+    mkdir = os.mkdir
+
+    unlink = os.unlink
+
+    if hasattr(os, "link"):
+        link = os.link
+    else:
+        def link(self, src, dst):
+            raise NotImplementedError("os.link() not available on this system")
+
+    rmdir = os.rmdir
+
+    rename = os.rename
+
+    replace = os.replace
+
+    if hasattr(os, "symlink"):
+        symlink = os.symlink
+    else:
+        def symlink(self, src, dst, target_is_directory=False):
+            raise NotImplementedError("os.symlink() not available on this system")
+
+    def touch(self, path, mode=0o666, exist_ok=True):
+        if exist_ok:
+            # First try to bump modification time
+            # Implementation note: GNU touch uses the UTIME_NOW option of
+            # the utimensat() / futimens() functions.
+            try:
+                os.utime(path, None)
+            except OSError:
+                # Avoid exception chaining
+                pass
+            else:
+                return
+        flags = os.O_CREAT | os.O_WRONLY
+        if not exist_ok:
+            flags |= os.O_EXCL
+        fd = os.open(path, flags, mode)
+        os.close(fd)
+
+    if hasattr(os, "readlink"):
+        readlink = os.readlink
+    else:
+        def readlink(self, path):
+            raise NotImplementedError("os.readlink() not available on this system")
+
+    def owner(self, path):
+        try:
+            import pwd
+            return pwd.getpwuid(self.stat(path).st_uid).pw_name
+        except ImportError:
+            raise NotImplementedError("Path.owner() is unsupported on this system")
+
+    def group(self, path):
+        try:
+            import grp
+            return grp.getgrgid(self.stat(path).st_gid).gr_name
+        except ImportError:
+            raise NotImplementedError("Path.group() is unsupported on this system")
+
+    getcwd = os.getcwd
+
+    expanduser = staticmethod(os.path.expanduser)
+
+    realpath = staticmethod(os.path.realpath)
+
 
 class _AsyncAccessor(_NormalAccessor):
   stat = to_async_method(os.stat)
@@ -47,12 +133,14 @@ class _AsyncAccessor(_NormalAccessor):
   rename = to_async_method(os.rename)
   replace = to_async_method(os.replace)
 
-  symlink = staticmethod(
-    to_async_method(_NormalAccessor.symlink)
-  )
+  if hasattr(_NormalAccessor, 'symlink'):
+    symlink = staticmethod(
+      to_async_method(_NormalAccessor.symlink)
+    )
 
   utime = to_async_method(os.utime)
-  readlink = to_async_method(_NormalAccessor.readlink)
+  if hasattr(_NormalAccessor, 'readlink'):
+    readlink = to_async_method(_NormalAccessor.readlink)
   remove = to_async_method(os.remove)
 
   async def owner(self, path: str) -> str:
@@ -63,7 +151,7 @@ class _AsyncAccessor(_NormalAccessor):
       return pwd.getpwuid(stat.st_uid).pw_name
 
     except ImportError:
-      raise NotImplementedError("Path.owner() is unsupported on this system")
+      raise NotImplementedError("AsyncPath.owner() is unsupported on this system")
 
   async def group(self, path: str) -> str:
     try:
@@ -73,7 +161,7 @@ class _AsyncAccessor(_NormalAccessor):
       return grp.getgrgid(stat.st_gid).gr_name
 
     except ImportError:
-      raise NotImplementedError("Path.group() is unsupported on this system")
+      raise NotImplementedError("AsyncPath.group() is unsupported on this system")
 
   async def scandir(self, *args, **kwargs) -> AsyncIterable[EntryWrapper]:
     async for entry in scandir_async(*args, **kwargs):
@@ -89,11 +177,12 @@ _async_accessor = _AsyncAccessor()
 
 class AsyncPurePath(PurePath):
   def _init(self, template: PurePath | None = None):
-    self._accessor = _async_accessor
+    self._accessor: _AsyncAccessor = _async_accessor
 
   def __new__(cls: type, *args):
     if cls is AsyncPurePath:
-      cls = AsyncPureWindowsPath if os.name == 'nt' else AsyncPurePosixPath
+      cls = AsyncPureWindowsPath if IS_WIN else AsyncPurePosixPath
+
     return cls._from_parts(args)
 
 
@@ -117,7 +206,7 @@ class AsyncPureWindowsPath(AsyncPurePath):
 
 class AsyncPath(Path, AsyncPurePath):
   _flavour = \
-    _async_windows_flavour if os.name == 'nt' else _async_posix_flavour
+    _async_windows_flavour if IS_WIN else _async_posix_flavour
   _accessor = _async_accessor
 
   def _init(self, template: AsyncPath | None = None):
@@ -125,7 +214,7 @@ class AsyncPath(Path, AsyncPurePath):
 
   def __new__(cls: type, *args, **kwargs):
     if cls is AsyncPath:
-      cls = AsyncWindowsPath if os.name == 'nt' else AsyncPosixPath
+      cls = AsyncWindowsPath if IS_WIN else AsyncPosixPath
 
     try:
       self = cls._from_parts(args, init=False)
@@ -327,7 +416,8 @@ class AsyncPath(Path, AsyncPurePath):
     Returns the new Path instance pointing to the target path.
     """
     await self._accessor.replace(self, target)
-    return type(self)(target)
+    cls = type(self)
+    return cls(target)
 
   async def symlink_to(self, target: str, target_is_directory: bool = False):
     """
@@ -403,9 +493,10 @@ class AsyncPath(Path, AsyncPurePath):
     """Iterate over the files in this directory.  Does not yield any
     result for the special paths '.' and '..'.
     """
-    for name in await self._accessor.listdir(self):
+    names = await self._accessor.listdir(self)
+
+    for name in names:
       if name in {'.', '..'}:
-        # Yielding a path object for these makes little sense
         continue
 
       yield self._make_child_relpath(name)
@@ -676,15 +767,6 @@ class AsyncPath(Path, AsyncPurePath):
 
     return self
 
-  async def iterdir(self) -> AsyncIterable[AsyncPath]:
-    names = await self._accessor.listdir(self)
-
-    for name in names:
-      if name in {'.', '..'}:
-        continue
-
-      yield self._make_child_relpath(name)
-
 
 class AsyncPosixPath(PosixPath, AsyncPath, AsyncPurePosixPath):
   __slots__ = ()
@@ -693,5 +775,5 @@ class AsyncPosixPath(PosixPath, AsyncPath, AsyncPurePosixPath):
 class AsyncWindowsPath(WindowsPath, AsyncPath, AsyncPureWindowsPath):
   __slots__ = ()
 
-  async def is_mount(self) -> int:
+  async def is_mount(self) -> bool:
     raise NotImplementedError("AsyncPath.is_mount() is unsupported on this system")
